Dialog
===========================

.. currentmodule:: enaml.widgets.dialog

.. autoclass:: Dialog


Backends
--------

Qt
^^

.. inheritance-diagram::
    enaml.widgets.qt.qt_dialog.QtDialog
    :parts: 1

.. autoclass:: enaml.widgets.qt.qt_dialog.QtDialog

Wx
^^

.. inheritance-diagram::
    enaml.widgets.wx.wx_dialog.WXDialog
    :parts: 1

.. autoclass:: enaml.widgets.wx.wx_dialog.WXDialog
